home · contact · privacy
Minor code rearrangements.
[plomrogue2-experiments] / client.py
index fa5d9c42a82d08f10b98a22f198f0d382fa79b3d..dd40323fca7038e45f8684bd1f34bd086e96523d 100755 (executable)
--- a/client.py
+++ b/client.py
@@ -4,10 +4,10 @@ import plom_socket_io
 import socket
 import threading
 from parser import ArgError, Parser
-from game_common import World
+from game_common import World, Commander
 
 
-class Game:
+class Game(Commander):
     world = World()
     log_text = ''
 
@@ -23,24 +23,10 @@ class Game:
             symbol = 'm'
         return symbol
 
-    def cmd_MAP_SIZE(self, yx):
-        """Set self.map_size to yx, redraw self.terrain_map as '?' cells."""
-        self.world.set_map_size(yx)
-    cmd_MAP_SIZE.argtypes = 'yx_tuple:nonneg'
-
-    def cmd_TERRAIN_LINE(self, y, terrain_line):
-        self.world.set_map_line(y, terrain_line)
-    cmd_TERRAIN_LINE.argtypes = 'int:nonneg string'
-
-    def cmd_THING_TYPE(self, i, type_):
-        t = self.world.get_thing(i)
-        t.type_ = type_
-    cmd_THING_TYPE.argtypes = 'int:nonneg string'
-
-    def cmd_THING_POS(self, i, yx):
-        t = self.world.get_thing(i)
-        t.position = list(yx)
-    cmd_THING_POS.argtypes = 'int:nonneg yx_tuple:nonneg'
+    def cmd_LAST_PLAYER_TASK_RESULT(self, msg):
+        if msg != "success":
+            self.log_text = msg + '\n' + self.log_text
+    cmd_LAST_PLAYER_TASK_RESULT.argtypes = 'string'
 
     def cmd_TURN_FINISHED(self, n):
         """Do nothing. (This may be extended later.)"""
@@ -53,6 +39,10 @@ class Game:
         self.world.things = []
     cmd_NEW_TURN.argtypes = 'int:nonneg'
 
+    def cmd_VISIBLE_MAP_LINE(self, y, terrain_line):
+        self.world.map_.set_line(y, terrain_line)
+    cmd_VISIBLE_MAP_LINE.argtypes = 'int:nonneg string'
+
 
 class WidgetManager:
 
@@ -69,13 +59,13 @@ class WidgetManager:
         self.top = urwid.Filler(widget_pile, valign='top')
 
     def draw_map(self):
"""Draw map view from .game.terrain_map, .game.things."""
         map_lines = []
-        map_size = len(self.game.world.terrain_map)
+        map_size = len(self.game.world.map_.terrain)
         start_cut = 0
         while start_cut < map_size:
-            limit = start_cut + self.game.world.map_size[1]
-            map_lines += [self.game.world.terrain_map[start_cut:limit]]
+            limit = start_cut + self.game.world.map_.size[1]
+            map_lines += [self.game.world.map_.terrain[start_cut:limit]]
             start_cut = limit
         for t in self.game.world.things:
             line_as_list = list(map_lines[t.position[0]])
@@ -69,13 +59,13 @@ class WidgetManager:
 
     def draw_map(self):
-        """Draw map view from .game.terrain_map, .game.things."""
+        """Draw map view from .game.map_.terrain, .game.things."""
         map_lines = []